# Voxface

Fast voxelation of the face in 3D structural MRI data combining spline downsampling with nearest-neighbor upsampling to
deidentify the face while retaining some signal intensity to guide whole-head registration.

### Typical Performance
Face voxelation of a typical 1 mm isotropic T1w image takes about 5 seconds on a 3.2 GHz 6-Core Intel Core i7 Mac Mini.
